#========================================================================================
# package      DE_EPAGES::CMS::API::Cartridge
# base         DE_EPAGES::Design::API::DesignInstaller
# state        public
#----------------------------------------------------------------------------------------
# description  This is the main cartridge class for install/patch/uninstall.
#========================================================================================
package DE_EPAGES::CMS::API::Cartridge;
use base DE_EPAGES::Design::API::DesignInstaller;

use strict;

#========================================================================================
# function     new
# state        private
#----------------------------------------------------------------------------------------
# syntax       $Installer = DE_EPAGES::CMS::API::Cartridge->new(%options);
#----------------------------------------------------------------------------------------
# description  Creates a new installer object of DE_EPAGES::CMS.
#----------------------------------------------------------------------------------------
# input        %options | options for un/install
#               <ul>
#                 <li>IsRecursive - recursive un/installation of required or dependent
#                     cartridges
#               </ul>
#               | hash
# return       $Installer | cartridge installer | object
#========================================================================================
sub new {
    my ($class, %options) = @_;

    my $self = __PACKAGE__->SUPER::new(
        %options,
        'CartridgeDirectory' => 'DE_EPAGES/CMS',
        'Version'            => '7.57.0',
        'Patches'            => ['7.2.0','7.3.0','7.4.0','7.5.0','7.6.0','7.7.0','7.8.0','7.9.0','7.10.0','7.11.0','7.12.0','7.13.0','7.14.0','7.15.0','7.16.0','7.17.0','7.18.0','7.19.0','7.20.0','7.21.0','7.22.0','7.23.0','7.24.0','7.25.0','7.26.0','7.27.0','7.28.0','7.29.0','7.30.0','7.31.0','7.32.0','7.33.0','7.34.0','7.35.0','7.36.0','7.37.0','7.38.0','7.39.0','7.40.0','7.41.0','7.42.0','7.43.0','7.44.0','7.45.0','7.46.0','7.47.0','7.48.0','7.49.0','7.50.0','7.51.0','7.52.0','7.53.0','7.54.0','7.55.0','7.56.0'],
    );
    return bless $self, $class;
}

#========================================================================================
# function     install
# state        private
#----------------------------------------------------------------------------------------
# syntax       $Installer->install;
#----------------------------------------------------------------------------------------
# description  Installs the cartridge.
#========================================================================================
sub install {
    my $self = shift;

    $self->startInstall;
    $self->SUPER::install;
    $self->finishInstall;
    return;
}

#========================================================================================
# function     uninstall
# state        private
#----------------------------------------------------------------------------------------
# syntax       $Installer->uninstall;
#----------------------------------------------------------------------------------------
# description  Uninstalls the cartridge.
#========================================================================================
sub uninstall {
    my $self = shift;

    $self->startUninstall;
    $self->SUPER::uninstall;
    $self->finishUninstall;
    return;
}

1;
