#========================================================================================
# package      DE_EPAGES::PayPalExpress::t::unit::UI_Basket
# base         DE_EPAGES::Core::API::Test
# state        public
#----------------------------------------------------------------------------------------
# description  Unit test for UI::Basket
#========================================================================================
package DE_EPAGES::PayPalExpress::t::unit::UI_Basket;
use base DE_EPAGES::Core::API::Test;
use strict;
use DE_EPAGES::Core::API::Error qw ( Error );
use DE_EPAGES::PayPalExpress::UI::Basket;
use DE_EPAGES::Test::Mock::EpagesObject;
use DE_EPAGES::Test::Mock::Mockify;
use Test::Mockify::Sut;
use Test::Mockify::Matcher qw ( Object String HashRef );
use Test::MockObject;
use Test::More;

sub test {
    my $self = shift;

    $self->test_InvalidBasket();
    $self->test_ShortcutButton_with_MultiStepCheckout();
    $self->test_ShortcutButton_with_ClassicalCheckout();
    $self->test_ShortcutButton_with_MobileCheckout();
    $self->test_ClassicOrMultistepCheckout_without_ShortcutButton();
    $self->test_ErrorHandling();
    $self->test_ShortcutButton_ErrorRedirection();
    $self->test_ClassicOrMultistepCheckout_ErrorRedirection();
    $self->test_ErrorRedirection_OrderedBasket();

    done_testing();
}
#----------------------------------------------------------------------------------------
sub test_InvalidBasket {
    my $self = shift;
    my $SubTestName = (caller(0))[3];

    my $BasketService = $self->_buildBasketService_with_InvalidBasket();
    my $UIBasket = $self->_buildUIBasket( $BasketService );
    my $Servlet = $self->_buildServlet_with_OrderForMultistepCheckout();

    my $Result = $UIBasket->PayPalExpressReturn( $Servlet );

    is( $Result, undef, "$SubTestName - tests error handling if the importBasket was not fine" );
}
#----------------------------------------------------------------------------------------
sub test_ShortcutButton_with_MultiStepCheckout {
    my $self = shift;
    my $SubTestName = (caller(0))[3];

    my $BasketService = $self->_buildBasketService_MultistepCheckout_with_ShortcutButton();
    my $UIBasket = $self->_buildUIBasket( $BasketService );
    my $Servlet = $self->_buildServlet_with_OrderForMultistepCheckout();

    my $Result = $UIBasket->PayPalExpressReturn( $Servlet );

    is( $Result, undef, "$SubTestName - tests if ExpressButton call with MultistepCheckout was used" );
    my $hServletVars = $Servlet->vars();
    my $hExpectedServletVars = {'ViewAction' => 'ViewMultiCheckoutConfirmation'};
    is_deeply( $hServletVars, $hExpectedServletVars, "$SubTestName - tests if the multistep view action is set" );
}
#----------------------------------------------------------------------------------------
sub test_ShortcutButton_with_ClassicalCheckout{
    my $self = shift;
    my $SubTestName = (caller(0))[3];

    my $BasketService = $self->_buildBasketService_ClassicCheckout_with_ShortcutButton();
    my $UIBasket = $self->_buildUIBasket( $BasketService );
    my $Servlet = $self->_buildServlet_with_OrderForClassicCheckout();

    my $Result = $UIBasket->PayPalExpressReturn( $Servlet );

    is( $Result, undef, "$SubTestName - tests if ExpressButton call with MultistepCheckout was used" );

    my $hServletVars = $Servlet->vars();
    my $hExpectedServletVars = {'ViewAction' => 'ViewOffer'};
    is_deeply( $hServletVars, $hExpectedServletVars, "$SubTestName - tests if the classic view action is set" );
}
#----------------------------------------------------------------------------------------
sub test_ShortcutButton_with_MobileCheckout {
    my $self = shift;
    my $SubTestName = (caller(0))[3];

    my $BasketService = $self->_buildBasketService_MultistepCheckout_with_ShortcutButton();
    my $UIBasket = $self->_buildUIBasket( $BasketService );
    my $Servlet = $self->_buildServlet_with_OrderForMobileCheckout();

    my $Result = $UIBasket->PayPalExpressReturn( $Servlet );

    is( $Result,undef,"$SubTestName - tests if ExpressButton call with Mobile was used" );

    my $hServletVars = $Servlet->vars();
    my $hExpectedServletVars = {'ViewAction' => 'ViewOffer'};
    is_deeply( $hServletVars, $hExpectedServletVars, "$SubTestName - tests if the classic view action is set" );
}
#----------------------------------------------------------------------------------------
sub test_ClassicOrMultistepCheckout_without_ShortcutButton {
    my $self = shift;
    my $SubTestName = (caller(0))[3];

    my $BasketService = $self->_buildBasketService_ClassicOrMultistepCheckout_without_ShortcutButton();
    my $UIBasket = $self->_buildUIBasket( $BasketService );
    my $Servlet = $self->_buildServlet_with_OrderForClassicCheckout();

    my $Result = $UIBasket->PayPalExpressReturn( $Servlet );

    is( $Result, 'FakeOrder', "$SubTestName - tests if ClassicalCheckout was used" );
}
#----------------------------------------------------------------------------------------
sub test_ErrorHandling{
    my $self = shift;
    my $SubTestName = (caller(0))[3];

    my $BasketService = $self->_createBasketService_ErrorTest();
    my $UIBasket = $self->_buildUIBasket( $BasketService );
    my $Servlet = $self->_buildServlet_with_OrderForClassicCheckout();

    $UIBasket->PayPalExpressReturn( $Servlet );

    my $hServletVars = $Servlet->vars();
    like( $hServletVars->{'ErrorGUID'}, qr/^[0-9A-F\-]+$/i, "$SubTestName - test the vars output for ErrorGUID" );
    is( $hServletVars->{'ViewAction'}, 'ViewPayPalExpressFailed', "$SubTestName - test the vars output for ViewAction" );
    is( $hServletVars->{'ErrorCode'}, 'GetExpressCheckoutDetailsError', "$SubTestName - test the vars output for ErrorCode" );
    is( $hServletVars->{'ErrorMessage'}, 'testNativeDie', "$SubTestName - test the vars output for ErrorMessage" );
}
#----------------------------------------------------------------------------------------
sub test_ShortcutButton_ErrorRedirection {
    my $self = shift;
    my $SubTestName = (caller(0))[3];

    my $BasketService = $self->_buildBasketService_ShortcutButton();
    my $UIBasket = $self->_buildUIBasket_ShortcutButton( $BasketService );
    my $Servlet = $self->_buildServlet_with_OrderForClassicCheckout();

    $UIBasket->PayPalExpressReturn( $Servlet );

    my $hServletVars = $Servlet->vars();
    is( $hServletVars->{'ViewAction'}, 'ViewPayPalExpressFailed', "$SubTestName - test the vars output for ViewAction" );
    is( $hServletVars->{'ErrorCode'}, 'PayPalExpressInvalid', "$SubTestName - test the vars output for ErrorCode" );
    is( $hServletVars->{'PPEErrorCode'}, 'errorCode', "$SubTestName - test the vars output for PPEErrorCode" );
    is( $hServletVars->{'PayPalMessage'}, 'errorMessage', "$SubTestName - test the vars output for PayPalMessage" );
}
#----------------------------------------------------------------------------------------
sub test_ClassicOrMultistepCheckout_ErrorRedirection {
    my $self = shift;
    my $SubTestName = (caller(0))[3];

    my $BasketService = $self->_buildBasketService_ClassicCheckout();
    my $UIBasket = $self->_buildUIBasket_ClassicCheckout( $BasketService );
    my $Servlet = $self->_buildServlet_with_OrderForClassicCheckout();

    $UIBasket->PayPalExpressReturn( $Servlet );

    my $hServletVars = $Servlet->vars();
    is( $hServletVars->{'ViewAction'}, 'ViewPayPalExpressFailed',"$SubTestName - test the vars output for ViewAction" );
    is( $hServletVars->{'ErrorCode'}, 'PayPalExpressInvalid',"$SubTestName - test the vars output for ErrorCode" );
    is( $hServletVars->{'PPEErrorCode'}, 'errorCode',"$SubTestName - test the vars output for PPEErrorCode" );
    is( $hServletVars->{'PayPalMessage'}, 'errorMessage',"$SubTestName - test the vars output for PayPalMessage" );
}
#----------------------------------------------------------------------------------------
sub test_ErrorRedirection_OrderedBasket {
    my $self = shift;
    my $SubTestName = (caller(0))[3];

    my $BasketService = $self->_buildBasketService_ClassicCheckout();
    my $UIBasket = $self->_buildUIBasket_ClassicCheckout_With_Error( $BasketService );
    my $Servlet = $self->_buildServlet_with_OrderedBasketForClassicCheckout();

    $UIBasket->PayPalExpressReturn( $Servlet );

    my $hServletVars = $Servlet->vars();
    is( $hServletVars->{'ViewAction'}, 'ViewPayPalExpressFailed',"$SubTestName - test the vars output for ViewAction" );
    is( $hServletVars->{'ErrorCode'}, 'PayPalExpressInvalid',"$SubTestName - test the vars output for ErrorCode" );
    is( $hServletVars->{'PPEErrorCode'}, '10486',"$SubTestName - test the vars output for PPEErrorCode" );
    is( $hServletVars->{'PayPalMessage'}, 'errorMessage',"$SubTestName - test the vars output for PayPalMessage" );
}
#----------------------------------------------------------------------------------------
# helpers
#----------------------------------------------------------------------------------------
sub _buildBasketService_ShortcutButton {
    my $self = shift;
    my $hSettings = {
        'IsButtonTransaction' => 1,
    };
    return $self->_createBasketService_ShortcutButton( $hSettings );
}
#----------------------------------------------------------------------------------------
sub _buildBasketService_ClassicCheckout {
    my $self = shift;
    my $hSettings = {
        'IsButtonTransaction' => 0,
    };
    return $self->_createBasketService_ShortcutButton( $hSettings );
}
#----------------------------------------------------------------------------------------
sub _createBasketService_ShortcutButton {
    my $self = shift;
    my ( $hSettings ) = @_;
    my $aParameterList = [];
    my $Mockify = DE_EPAGES::Test::Mock::Mockify->new(
                   'DE_EPAGES::PayPalExpress::API::Webservice::BasketService',
                   $aParameterList
              );
    $Mockify->addMockWithReturnValueAndParameterCheck( 'importBasket', 1, [{'object'=>'DE_EPAGES::Order::API::Object::Basket'}] );
    $Mockify->addMockWithReturnValue( 'wasTriggeredWithShortcutButton', $hSettings->{'IsButtonTransaction'} );
    return $Mockify->getMockObject();
}
#----------------------------------------------------------------------------------------
sub _buildUIBasket_ShortcutButton {
   my $self = shift;
    my ( $BasketService ) = @_;

    my $hSettingsExpressCheckoutDetails = {
        'ReturnValue_doRequestForShortcutButtonCheckout' => 0,
        'ReturnValue_doRequestForClassicOrMultistepCheckout' => 1,
    };

    my $hSettingsUIBasket = {
        'BasketService' => $BasketService,
        'ExpressCheckoutDetails' => $self->_createGetExpressCheckoutDetails( $hSettingsExpressCheckoutDetails ),
    };
    return $self->_createUIBasket( $hSettingsUIBasket );
}
#----------------------------------------------------------------------------------------
sub _buildUIBasket_ClassicCheckout {
   my $self = shift;
    my ( $BasketService ) = @_;

    my $hSettingsExpressCheckoutDetails = {
        'ReturnValue_doRequestForShortcutButtonCheckout' => 0,
        'ReturnValue_doRequestForClassicOrMultistepCheckout' => 0,
    };

    my $hSettingsUIBasket = {
        'BasketService' => $BasketService,
        'ExpressCheckoutDetails' => $self->_createGetExpressCheckoutDetails( $hSettingsExpressCheckoutDetails ),
    };
    return $self->_createUIBasket( $hSettingsUIBasket );
}
#----------------------------------------------------------------------------------------
sub _buildUIBasket_ClassicCheckout_With_Error {
   my $self = shift;
    my ( $BasketService ) = @_;

    my $hSettingsExpressCheckoutDetails = {
        'ReturnValue_doRequestForShortcutButtonCheckout' => 0,
        'ReturnValue_doRequestForClassicOrMultistepCheckout' => 0,
    };

    my $hSettingsUIBasket = {
        'BasketService' => $BasketService,
        'ExpressCheckoutDetails' => $self->_createGetExpressCheckoutDetails( $hSettingsExpressCheckoutDetails ),
        'ReturnValue_DocheckoutPayment_Error' => 1
    };
    return $self->_createUIBasket( $hSettingsUIBasket );
}
#----------------------------------------------------------------------------------------
sub _buildUIBasket {
    my $self = shift;
    my ( $BasketService ) = @_;

    my $hSettingsExpressCheckoutDetails = {
        'ReturnValue_doRequestForShortcutButtonCheckout' => 1,
        'ReturnValue_doRequestForClassicOrMultistepCheckout' => 1,
    };

    my $hSettingsUIBasket = {
        'BasketService' => $BasketService,
        'ExpressCheckoutDetails' => $self->_createGetExpressCheckoutDetails( $hSettingsExpressCheckoutDetails ),
    };
    return $self->_createUIBasket( $hSettingsUIBasket );
}
#----------------------------------------------------------------------------------------
sub _createUIBasket {
    my $self = shift;
    my ( $hSettings ) = @_;

    my $aParameterList = [];
    my $MockifySut = Test::Mockify::Sut->new(
        'DE_EPAGES::PayPalExpress::UI::Basket',
        $aParameterList
    );
    $MockifySut->mock('_createBasketService')
        ->when()->thenReturn( $hSettings->{'BasketService'} );

    $MockifySut->mock('_createWebserviceGetExpressCheckoutDetails')
        ->when()->thenReturn( $hSettings->{'ExpressCheckoutDetails'} );

    $MockifySut->mock('_LogError')
        ->when(Object('DE_EPAGES::Core::API::Error'))->thenReturn(1);

    $MockifySut->mock('_doBasket2Order')
        ->when(Object('DE_EPAGES::Presentation::Servlet::Permission'), Object('DE_EPAGES::Order::API::Object::Basket'))
        ->thenReturn('FakeOrder');

    $MockifySut->mock('_logRequest')
        ->when(Object('DE_EPAGES::Presentation::Servlet::Permission'))->thenReturnUndef();

    $MockifySut->mockImported('DE_EPAGES::Object::API::Factory', 'LoadObjectByGUID')
        ->when()->thenReturn($self->_createCustomerOrder());

    $MockifySut->mockImported('DE_EPAGES::ExternalPayment::API::Log', 'LogPayment')
        ->when(String(), HashRef())->thenReturnUndef();

    if ($hSettings->{'ReturnValue_DocheckoutPayment_Error'}) {
        $MockifySut->mockImported('DE_EPAGES::Core::API::Error', 'ExistsError')
            ->when()->thenReturn(1);

        $MockifySut->mockImported('DE_EPAGES::Core::API::Error', 'GetError')
            ->when()->thenReturn($self->_createError());

        
    }

    return $MockifySut->getMockObject();
}
#----------------------------------------------------------------------------------------
sub _createError {
    my $self = shift;
    my ( $hSettings ) = @_;

    my $hresult = {
            'Ack'           => 'ACK',
            'ErrorCode'     => '10486',
            'LongMessage'   => 'errorMessage',
            'CorrelationID' => 'CORRELATIONID',
            'Response'      => {}
        };

    my $aParameterList = [];
    my $Mockify = Test::Mockify->new(
                   'DE_EPAGES::Core::API::Error',
                   $aParameterList
              );

    $Mockify->mock('code')
        ->when()->thenReturn('PayPalExpressFailed');

    $Mockify->mock('vars')
        ->when()->thenReturn($hresult);

    return $Mockify->getMockObject();
}
#----------------------------------------------------------------------------------------
sub _createGetExpressCheckoutDetails {
    my $self = shift;
    my ( $hSettings ) = @_;

    my $aParameterList = [];
    my $Mockify = DE_EPAGES::Test::Mock::Mockify->new(
                   'DE_EPAGES::PayPalExpress::API::Webservice::GetExpressCheckoutDetails',
                   $aParameterList
              );
    my $aParameterTypes = [
        {'object' => 'DE_EPAGES::PayPalExpress::API::Webservice::BasketService'},
        {'object' => 'DE_EPAGES::Presentation::Servlet::Permission'},
    ];
    my $getErrorMessageValue = 'errorMessage';
    my $getErrorCodeValue = 'errorCode';

    $Mockify->addMockWithReturnValueAndParameterCheck(
        'doRequestForShortcutButtonCheckout',
        $hSettings->{'ReturnValue_doRequestForShortcutButtonCheckout'},
        $aParameterTypes
    );
    $Mockify->addMockWithReturnValueAndParameterCheck(
        'doRequestForClassicOrMultistepCheckout',
        $hSettings->{'ReturnValue_doRequestForClassicOrMultistepCheckout'},
        $aParameterTypes
    );
    $Mockify->addMockWithReturnValue( 'getErrorMessage', $getErrorMessageValue );
    $Mockify->addMockWithReturnValue( 'getErrorCode', $getErrorCodeValue );

    return $Mockify->getMockObject();
}
#----------------------------------------------------------------------------------------
sub _buildBasketService_with_InvalidBasket {
    my $self = shift;
    my $hSettings = {
        'ImportBasket' => 0,
    };
    return $self->_createBasketService( $hSettings );
}
#----------------------------------------------------------------------------------------
sub _buildBasketService_MultistepCheckout_with_ShortcutButton {
    my $self = shift;
    my $hSettings = {
        'ImportBasket' => 1,
        'IsButtonTransaction' => 1,
        'IsMultistepCheckout' => 1,
    };
    return $self->_createBasketService( $hSettings );
}
#----------------------------------------------------------------------------------------
sub _buildBasketService_ClassicCheckout_with_ShortcutButton {
    my $self = shift;
    my $hSettings = {
        'ImportBasket' => 1,
        'IsButtonTransaction' => 1,
        'IsMultistepCheckout' => 0,
    };
    return $self->_createBasketService( $hSettings );
}
#----------------------------------------------------------------------------------------
sub _buildBasketService_ClassicOrMultistepCheckout_without_ShortcutButton {
    my $self = shift;
    my $hSettings = {
        'ImportBasket' => 1,
        'IsButtonTransaction' => 0,
        'IsMultistepCheckout' => 0,
        'Basket' => $self->_createBasket(),
    };
    return $self->_createBasketService( $hSettings );
}
#----------------------------------------------------------------------------------------
sub _createBasketService {
    my $self = shift;
    my ( $hSettings ) = @_;

    my $aParameterList = [];
    my $Mockify = DE_EPAGES::Test::Mock::Mockify->new(
                   'DE_EPAGES::PayPalExpress::API::Webservice::BasketService',
                   $aParameterList,
    );
    $Mockify->addMockWithReturnValueAndParameterCheck( 'importBasket', $hSettings->{'ImportBasket'}, [{'object'=>'DE_EPAGES::Order::API::Object::Basket'}] );
    $Mockify->addMockWithReturnValue( 'wasTriggeredWithShortcutButton', $hSettings->{'IsButtonTransaction'} );
    $Mockify->addMockWithReturnValue( 'isMultistepCheckout', $hSettings->{'IsMultistepCheckout'} );
    $Mockify->addMockWithReturnValue( 'getBasket',$self->_createBasket() );
    return $Mockify->getMockObject();
}
#----------------------------------------------------------------------------------------
sub _createBasketService_ErrorTest {
    my $self = shift;

    my $aParameterList = [];
    my $Mockify = DE_EPAGES::Test::Mock::Mockify->new(
                   'DE_EPAGES::PayPalExpress::API::Webservice::BasketService',
                   $aParameterList,
    );
    $Mockify->addMockWithReturnValueAndParameterCheck( 'importBasket', 1, [{'object'=>'DE_EPAGES::Order::API::Object::Basket'}] );
    $Mockify->addMock( 'wasTriggeredWithShortcutButton', sub { Error('testNativeDie'); } );
    return $Mockify->getMockObject();
}
#----------------------------------------------------------------------------------------
sub _buildServlet_with_OrderForClassicCheckout {
    my $self = shift;
    my $IsMultistepCheckout = 0;
    my $ServletSettings = {
        'BasketObject' => $self->_createBasket( $IsMultistepCheckout ),
        'UserObject' => $self->_createUser(),
        'IsMobileSwitch' => 0,
    };
    return $self->_createServlet( $ServletSettings );
}
#----------------------------------------------------------------------------------------
sub _buildServlet_with_OrderedBasketForClassicCheckout {
    my $self = shift;
    my $IsMultistepCheckout = 0;
    my $IsOrderedBasket = 1;
    my $ServletSettings = {
        'BasketObject' => $self->_createBasket( $IsMultistepCheckout, $IsOrderedBasket ),
        'UserObject' => $self->_createUser(),
        'IsMobileSwitch' => 0,
    };
    return $self->_createServlet( $ServletSettings );
}
#----------------------------------------------------------------------------------------
sub _buildServlet_with_OrderForMultistepCheckout {
    my $self = shift;
    my $IsMultistepCheckout = 1;
    my $ServletSettings = {
        'BasketObject' => $self->_createBasket( $IsMultistepCheckout ),
        'UserObject' => $self->_createUser(),
        'IsMobileSwitch' => 0,
    };
    return $self->_createServlet( $ServletSettings );
}
#----------------------------------------------------------------------------------------
sub _buildServlet_with_OrderForMobileCheckout {
    my $self = shift;
    my $IsMultistepCheckout = 1;
    my $ServletSettings = {
        'BasketObject' => $self->_createBasket( $IsMultistepCheckout ),
        'UserObject' => $self->_createUser(),
        'IsMobileSwitch' => 1,
    };
    return $self->_createServlet( $ServletSettings );
}
#----------------------------------------------------------------------------------------
sub _createServlet {
    my $self = shift;
    my ($hServletSettings) = @_;

    my $aParameterList = [];
    my $Mockify = DE_EPAGES::Test::Mock::Mockify->new(
                   'DE_EPAGES::Presentation::Servlet::Permission',
                   $aParameterList
    );
    $Mockify->addMockWithReturnValue( 'object', $hServletSettings->{'BasketObject'} );
    $Mockify->addMockWithReturnValue( 'user', $hServletSettings->{'UserObject'} );
    $Mockify->addMockWithReturnValueAndParameterCheck( 'cookies', undef, [{'string'=>'RedirectPPE'}, {'int'=>0}] );
    $Mockify->addMockWithReturnValueAndParameterCheck( 'params', $hServletSettings->{'IsMobileSwitch'}, [{'string'=>'IsMobile'}] );

    return $Mockify->getMockObject();
}
#----------------------------------------------------------------------------------------
sub _createBasket {
    my $self = shift;
    my ($IsMultistepCheckout, $IsOrderedBasket) = @_;
    my $Shop = $self->_createShop( $IsMultistepCheckout );

    my $Alias  = $IsOrderedBasket ? 'OrderedBaskets' : 'Alias';

    my $hAtributes = {
        'User' => $self->_createUser(),
        'Site' => $Shop,
        'Shop' => $Shop,
        'OrderGUID' => '12312',
        'ID' => '123122',
        'Parent' => Test::MockObject->new()->mock( 'alias', sub { return $Alias } )
    };
    my $Basket = DE_EPAGES::Test::Mock::EpagesObject->new( 'DE_EPAGES::Order::API::Object::Basket', $hAtributes );

    return $Basket;
}
#----------------------------------------------------------------------------------------
sub _createUser {
    my $self = shift;

    my $hAtributes = {
        'ID' => 12345,
    };
    my $User = DE_EPAGES::Test::Mock::EpagesObject->new( 'DE_EPAGES::Permission::API::Object::User', $hAtributes );

    return $User;
}
#----------------------------------------------------------------------------------------
sub _createShop {
    my $self = shift;
    my ($IsMultistepCheckout) = @_;
    my $hAtributes = {
        'OrderProcess' => $IsMultistepCheckout,
        'IsUnityRegistered' => 0
    };
    my $Shop = DE_EPAGES::Test::Mock::EpagesObject->new( 'DE_EPAGES::Shop::API::Object::Shop', $hAtributes );

    return $Shop;
}
#----------------------------------------------------------------------------------------
sub _createCustomerOrder {
    my $self = shift;

    my $hAttributes = {
        'LineItemContainer' => $self->_createLineItemContainer(),
        'PaidOn' => undef,
        'ID' => '1231312',
    };
    my $CustomerOrder = DE_EPAGES::Test::Mock::EpagesObject->new( 'DE_EPAGES::Order::API::Object::CustomerOrder', $hAttributes );

    return $CustomerOrder;
}
#----------------------------------------------------------------------------------------
sub _createLineItemContainer {
    my $self = shift;

    my $hAttributes = {
        'Payment' => $self->_createLineItemPayment(),
        'GrandTotal' => '70.65',
        'CurrencyID' => 'EUR',
    };
    my $LineItemContainer = DE_EPAGES::Test::Mock::EpagesObject->new( 'DE_EPAGES::Order::API::Object::LineItemContainer', $hAttributes );

    return $LineItemContainer;
}
#----------------------------------------------------------------------------------------
sub _createLineItemPayment {
    my $self = shift;

    my $hAttributes = {
        'PayerID' => 'someID',
        'TransID2' => 'Dummmy_PaymentId',
        'Amount' => undef,
        'TransStatus' => undef,
        'TransTime' => undef,
        'IsIPNProcessed' => 0,
    };
    my $LineItemPayment = DE_EPAGES::Test::Mock::EpagesObject->new( 'DE_EPAGES::PayPalExpress::API::Object::LineItemPaymentPayPalExpress', $hAttributes );

    return $LineItemPayment;
}

__PACKAGE__->runScript();
