#========================================================================================
# package      DE_EPAGES::PayPalPlus::API::RatenkaufBannerScriptTagService
# state        public
#----------------------------------------------------------------------------------------
# description  RatenkaufBannerScriptTagService class
#========================================================================================
package DE_EPAGES::PayPalPlus::API::RatenkaufBannerScriptTagService;
use base qw ( Exporter );

use DE_EPAGES::PayPalPlus::API::ContextLogger;
use DE_EPAGES::PayPalPlus::API::Logger;
use DE_EPAGES::AppStore::API::Shop qw ( GetUnityScriptTagsApp );

use strict;

use constant VIEWACTION_RATENKAUF_BANNER => '?ViewAction=UnityViewRatenkaufBannerScript';

#========================================================================================
# function     new
# state        public
#----------------------------------------------------------------------------------------
# syntax       new( );
#----------------------------------------------------------------------------------------
# description  constuctor
#----------------------------------------------------------------------------------------
# return       $self | self | DE_EPAGES::PayPalPlus::API::RatenkaufBannerScriptTagService
#========================================================================================
sub new {
    my $class = shift;
    my ($PaymentMethod) = @_;

    my $self  = bless {
        'PaymentMethod' => $PaymentMethod,
        'Shop' => $PaymentMethod->getSite(),
    }, $class;
    return $self;
}

#========================================================================================
# function     addScriptTag
#----------------------------------------------------------------------------------------
# syntax       $RatenkaufBannerScriptTagService->addScriptTag();
#----------------------------------------------------------------------------------------
# description  Inserts script tag for Unity shops
#========================================================================================
sub addScriptTag {
    my $self = shift;
    my $MethodName    = ( caller(0) )[3];

    my $PaymentMethod = $self->{'PaymentMethod'};
    my $Shop = $self->{'Shop'};

    return unless (
        $Shop->get('IsUnityRegistered')
        && $PaymentMethod->usableAtStorefront()
        && $PaymentMethod->get('IsRatenkaufBannerVisible')
    );

    my $Context = $self->_createLogContext();

    $Context->logContext($PaymentMethod, $MethodName, sub {
        # get app client to communicate with the epagesJ REST API
        my $AppsClient = GetUnityScriptTagsApp($Shop);

        my $RatenkaufBannerScriptTagUrl = $self->_getRatenkaufBannerScriptTagUrl();

        # post new script tag, in case there has not been any so far
        $AppsClient->addScriptTag($RatenkaufBannerScriptTagUrl);

        my $Logger = $self->_createLogger();
        $Logger->logPayment('Added Script Tag for RatenkaufBanner', {'ScriptTagUrl' => $RatenkaufBannerScriptTagUrl});
    });
    return;
}

#========================================================================================
# function     deleteScriptTag
#----------------------------------------------------------------------------------------
# syntax       $RatenkaufBannerScriptTagService->deleteScriptTag();
#----------------------------------------------------------------------------------------
# description  Deletes script tag for Unity shops
#========================================================================================
sub deleteScriptTag {
    my $self = shift;
    my $MethodName    = ( caller(0) )[3];

    my $PaymentMethod = $self->{'PaymentMethod'};
    my $Shop = $self->{'Shop'};

    return unless $Shop->get('IsUnityRegistered');

    my $Context = $self->_createLogContext();

    $Context->logContext($PaymentMethod, $MethodName, sub {
        # get app client to communicate with the epagesJ REST API
        my $AppsClient = GetUnityScriptTagsApp($Shop);

        my $RatenkaufBannerScriptTagUrl = $self->_getRatenkaufBannerScriptTagUrl();

        # delete existing script-tag
        $AppsClient->deleteScriptTag($RatenkaufBannerScriptTagUrl);

        my $Logger = $self->_createLogger();
        $Logger->logPayment('Removed Script Tag for RatenkaufBanner', {'ScriptTagUrl' => $RatenkaufBannerScriptTagUrl});
    });

     return;
}

#----------------------------------------------------------------------------------------
sub _getRatenkaufBannerScriptTagUrl {
    my $self = shift;

    return $self->{'Shop'}->get('WebServerScriptName') . VIEWACTION_RATENKAUF_BANNER;
}
#----------------------------------------------------------------------------------------
sub _createLogContext {
    my $self = shift;
    return DE_EPAGES::PayPalPlus::API::ContextLogger->new();
}
#----------------------------------------------------------------------------------------
sub _createLogger{
    my $self = shift;
    return DE_EPAGES::PayPalPlus::API::Logger->new();
}

1;
