#========================================================================================
# package      DE_EPAGES::PayPalPlus::t::unit::RatenkaufBannerScriptTagService
# state        public
#----------------------------------------------------------------------------------------
# description  unit test for API::RatenkaufBannerScriptTagService
#========================================================================================
package DE_EPAGES::PayPalPlus::t::unit::RatenkaufBannerScriptTagService;
use base DE_EPAGES::Core::API::Test;
use DE_EPAGES::PayPalPlus::API::RatenkaufBannerScriptTagService;
use DE_EPAGES::Test::Mock::MockifyEpagesObject;
use DE_EPAGES::Test::Mock::Mockify qw ( WasCalled );
use Test::Exception;
use Test::More;
use Test::Mockify;
use Test::Mockify::Sut;
use Test::Mockify::Matcher qw ( String HashRef );
use Test::MockObject;
use strict;

use constant WEBSERVER_SCRIPT_NAME => 'WebServerScriptName.de\\';

sub test {
    my $self = shift;

    $self->test_addScriptTag_success();
    $self->test_addScriptTag_notUnity();
    $self->test_addScriptTag_RatenkaufNotVisible();
    $self->test_addScriptTag_NotUsableAtStorefront();

    $self->test_deleteScriptTag_success();
    $self->test_deleteScriptTag_notUnity();

    done_testing();
}
#----------------------------------------------------------------------------------------
sub test_addScriptTag_success {
    my $self = shift;
    my $SubTestName = (caller(0))[3];

    my $IsUnityRegistered = '1';
    my $IsRatenkaufBannerVisible = '1';
    my $IsUsableAtStorefront = '1';

    my $MockedShop = $self->_createShop($IsUnityRegistered);
    my $MockedPayPalPlus = $self->_createPaymentMethodPayPalPlusWithAttributeValues($MockedShop, $IsRatenkaufBannerVisible, $IsUsableAtStorefront);

    my $MockedScriptTagAppClient =$self->_createScriptTagAppClient();

    my $SUT = $self->_createSUT($MockedScriptTagAppClient, $MockedPayPalPlus);

    lives_ok(sub { $SUT->addScriptTag() }, "$SubTestName - tests if 'addScriptTag' does not die");

    ok( WasCalled($SUT, 'GetUnityScriptTagsApp'), "$SubTestName - GetUnityScriptTagsApp was called");

    is( $MockedScriptTagAppClient->call_pos(1),'addScriptTag',  "$SubTestName - 'addScriptTag' was called" );

    is( ($MockedScriptTagAppClient->call_args(1))[1],
        WEBSERVER_SCRIPT_NAME.'?ViewAction=UnityViewRatenkaufBannerScript',
        "$SubTestName - ScriptTag Url passed to 'addScriptTag' is correct" );

}

sub test_addScriptTag_notUnity {
    my $self = shift;
    my $SubTestName = (caller(0))[3];

    my $IsUnityRegistered = '0';
    my $IsRatenkaufBannerVisible = '1';
    my $IsUsableAtStorefront = '1';

    my $MockedShop = $self->_createShop($IsUnityRegistered);
    my $MockedPayPalPlus = $self->_createPaymentMethodPayPalPlusWithAttributeValues($MockedShop, $IsRatenkaufBannerVisible, $IsUsableAtStorefront);

    my $MockedScriptTagAppClient =$self->_createScriptTagAppClient();

    my $SUT = $self->_createSUT($MockedScriptTagAppClient, $MockedPayPalPlus);

    lives_ok(sub { $SUT->addScriptTag() }, "$SubTestName - tests if 'addScriptTag' does not die");

    ok(!WasCalled($SUT, 'GetUnityScriptTagsApp'), "$SubTestName - GetUnityScriptTagsApp was not called");
}

sub test_addScriptTag_RatenkaufNotVisible {
    my $self = shift;
    my $SubTestName = (caller(0))[3];

    my $IsUnityRegistered = '1';
    my $IsRatenkaufBannerVisible = '0';
    my $IsUsableAtStorefront = '1';

    my $MockedShop = $self->_createShop($IsUnityRegistered);
    my $MockedPayPalPlus = $self->_createPaymentMethodPayPalPlusWithAttributeValues($MockedShop, $IsRatenkaufBannerVisible, $IsUsableAtStorefront);

    my $MockedScriptTagAppClient =$self->_createScriptTagAppClient();

    my $SUT = $self->_createSUT($MockedScriptTagAppClient, $MockedPayPalPlus);

    lives_ok(sub { $SUT->addScriptTag() }, "$SubTestName - tests if 'addScriptTag' does not die");

    ok(!WasCalled($SUT, 'GetUnityScriptTagsApp'), "$SubTestName - GetUnityScriptTagsApp was not called");
}

sub test_addScriptTag_NotUsableAtStorefront {
    my $self = shift;
    my $SubTestName = (caller(0))[3];

    my $IsUnityRegistered = '1';
    my $IsRatenkaufBannerVisible = '1';
    my $IsUsableAtStorefront = '0';

    my $MockedShop = $self->_createShop($IsUnityRegistered);
    my $MockedPayPalPlus = $self->_createPaymentMethodPayPalPlusWithAttributeValues($MockedShop, $IsRatenkaufBannerVisible, $IsUsableAtStorefront);

    my $MockedScriptTagAppClient =$self->_createScriptTagAppClient();

    my $SUT = $self->_createSUT($MockedScriptTagAppClient, $MockedPayPalPlus);

    lives_ok(sub { $SUT->addScriptTag() }, "$SubTestName - tests if 'addScriptTag' does not die");

    ok(!WasCalled($SUT, 'GetUnityScriptTagsApp'), "$SubTestName - GetUnityScriptTagsApp was not called");
}

sub test_deleteScriptTag_success {
    my $self = shift;
    my $SubTestName = (caller(0))[3];

    my $IsUnityRegistered = '1';
    my $IsRatenkaufBannerVisible = '1';
    my $IsUsableAtStorefront = '1';

    my $MockedShop = $self->_createShop($IsUnityRegistered);
    my $MockedPayPalPlus = $self->_createPaymentMethodPayPalPlusWithAttributeValues($MockedShop, $IsRatenkaufBannerVisible, $IsUsableAtStorefront);

    my $MockedScriptTagAppClient =$self->_createScriptTagAppClient();

    my $SUT = $self->_createSUT($MockedScriptTagAppClient, $MockedPayPalPlus);

    lives_ok(sub { $SUT->deleteScriptTag() }, "$SubTestName - tests if 'deleteScriptTag' does not die");

    ok( WasCalled($SUT, 'GetUnityScriptTagsApp'), "$SubTestName - GetUnityScriptTagsApp was called");

    is( $MockedScriptTagAppClient->call_pos(1),'deleteScriptTag',  "$SubTestName - 'deleteScriptTag' was called" );

    is( ($MockedScriptTagAppClient->call_args(1))[1],
        WEBSERVER_SCRIPT_NAME.'?ViewAction=UnityViewRatenkaufBannerScript',
        "$SubTestName - ScriptTag Url passed to 'deleteScriptTag' is correct" );

}

sub test_deleteScriptTag_notUnity {
    my $self = shift;
    my $SubTestName = (caller(0))[3];

    my $IsUnityRegistered = '0';
    my $IsRatenkaufBannerVisible = '1';
    my $IsUsableAtStorefront = '1';

    my $MockedShop = $self->_createShop($IsUnityRegistered);
    my $MockedPayPalPlus = $self->_createPaymentMethodPayPalPlusWithAttributeValues($MockedShop, $IsRatenkaufBannerVisible, $IsUsableAtStorefront);

    my $MockedScriptTagAppClient =$self->_createScriptTagAppClient();

    my $SUT = $self->_createSUT($MockedScriptTagAppClient, $MockedPayPalPlus);

    lives_ok(sub { $SUT->deleteScriptTag() }, "$SubTestName - tests if 'deleteScriptTag' does not die");

    ok(!WasCalled($SUT, 'GetUnityScriptTagsApp'), "$SubTestName - GetUnityScriptTagsApp was not called");
}

#---------------------------------------------------------------------------
#  Helpers
#---------------------------------------------------------------------------
sub _createPaymentMethodPayPalPlusWithAttributeValues {
    my $self = shift;
    my ( $MockedShop, $IsRatenkaufBannerVisible, $IsUsableAtStorefront ) = @_;

    my $hAttributes = {
        'Alias' => 'PayPalPLUS',
        'ClientId' => 'ClientId_PaymentMethod',
        'ClientSecret' => 'ClientSecret_PaymentMethod',
        'ID' => '12345',
        'Path' => '/Shops/NemoShop/PaymentMethods/PayPalPlusTest',
        'Site' => $MockedShop,
        'IsRatenkaufBannerVisible' => $IsRatenkaufBannerVisible,
    };
    my $Mockify = DE_EPAGES::Test::Mock::MockifyEpagesObject->new( 'DE_EPAGES::PayPalPlus::API::Object::PaymentMethodPayPalPlus', $hAttributes );

    $Mockify->mock('usableAtStorefront', sub {return $IsUsableAtStorefront;});

    return $Mockify->getMockObject();
}
#----------------------------------------------------------------------------------------
sub _createShop {
    my $self = shift;
    my ($IsUnityRegistered) = @_;

    my $hAttributes = {
        'ID' => '23456',
        'Alias' => 'NemoShop',
        'OrderProcess' => 1,
        'IsUnityRegistered' => $IsUnityRegistered,
        'WebServerScriptName' =>  WEBSERVER_SCRIPT_NAME,
    };
    my $Mockify = DE_EPAGES::Test::Mock::MockifyEpagesObject->new( 'DE_EPAGES::Shop::API::Object::Shop', $hAttributes );
    return $Mockify->getMockObject();
}
#----------------------------------------------------------------------------------------
sub _createSUT {
    my $self = shift;
    my ($MockedScriptTagAppClient, $MockedPaymentMethod) = @_;

    my $aParameterList = [$MockedPaymentMethod];
    my $MockifySut = Test::Mockify::Sut->new('DE_EPAGES::PayPalPlus::API::RatenkaufBannerScriptTagService', $aParameterList);

    $MockifySut->mock('_createLogContext')->when()->thenReturn($self->_createContextLogger());
    $MockifySut->mock('_createLogger')->when()->thenReturn($self->_createLogger());

    $MockifySut->mockImported('DE_EPAGES::AppStore::API::Shop', 'GetUnityScriptTagsApp')
        ->whenAny()
        ->thenReturn($MockedScriptTagAppClient);

    return $MockifySut->getMockObject();
}
#----------------------------------------------------------------------------------------
sub _createScriptTagAppClient {
    my $self = shift;

    my $mock = Test::MockObject->new();
    $mock->set_true( 'addScriptTag' );
    $mock->set_true( 'deleteScriptTag' );

    return $mock;
}
#----------------------------------------------------------------------------------------
sub _createContextLogger {
    my $self = shift;

    my $Mockify = DE_EPAGES::Test::Mock::Mockify->new( 'DE_EPAGES::PayPalPlus::API::ContextLogger', [] );
    $Mockify->addMock('logContext',
        sub {
            my $InternalSelf = shift;
            $InternalSelf->{'__ToCheck'}->{'_Params_logContext'} = \@_;
            my $FunctionPointer = $InternalSelf->{'__ToCheck'}->{'_Params_logContext'}[2];
            return $FunctionPointer->();
        }
    );
    return $Mockify->getMockObject();
}
#----------------------------------------------------------------------------------------
sub _createLogger {
    my $self = shift;
    my ($LogData) = @_;
    my $aParameterList = [];
    my $Mockify = Test::Mockify->new(
                   'DE_EPAGES::PayPalPlus::API::Logger',
                   $aParameterList
              );
    $Mockify->mock('logOnboarding')->when(HashRef())->thenReturnUndef();
    $Mockify->mock('logPayment')->when(String(), HashRef())->thenReturnUndef();
    return $Mockify->getMockObject();
}

__PACKAGE__->runScript();
