#==================================================================================================
# package      DE_EPAGES::Paybox::UI::Shop
# state        public
# description  UI class
#==================================================================================================
package DE_EPAGES::Paybox::UI::Shop;
use base DE_EPAGES::Order::UI::Shop;

use strict;

use DE_EPAGES::Core::API::Error qw (
    ExistsError
    GetError
);
use DE_EPAGES::Core::API::Log qw (
    GetLog
    LogCommunication
    LogError
);

use DE_EPAGES::Paybox::API::PaymentCallbackParams;

use DE_EPAGES::Paybox::API::GatewayInterface::PaymentGatewayFactory qw (
    LoadPaymentGatewayConfigurator
    LoadPaymentGateway
);
use DE_EPAGES::Paybox::API::PaymentDispatcher qw (
    LoadPaymentDispatcher
);


#==================================================================================================
# function     TransactionPaymentName
# state        private
#--------------------------------------------------------------------------------------------------
# syntax       $Name = $Handler->TransactionPaymentName();
#--------------------------------------------------------------------------------------------------
# description  Name of PaymentType for search/view
#--------------------------------------------------------------------------------------------------
# return       $Name | name of payment type | string
#==================================================================================================
sub TransactionPaymentName { 'Paybox' }

#==================================================================================================
# Handler triggered from a redirect in the customer browser from the Paybox service
#==================================================================================================
sub BacklinkPayment {
    my $self = shift;
    my ($Servlet) = @_;

    GetLog('Paybox')->debug('BacklinkPayment');

    $self->BlockMonitor($Servlet);

    LogCommunication('Backlink parameters', $Servlet->params, 'Paybox');

    my $CallbackParams = DE_EPAGES::Paybox::API::PaymentCallbackParams->new($Servlet->params);
    my $Shop = $Servlet->object;
    my $hResult = {} ;
    eval {
        my $GatewayConfigurator = LoadPaymentGatewayConfigurator( $CallbackParams->getPaymentMethodID() );
        my $PaymentGateway = LoadPaymentGateway($GatewayConfigurator);
        $hResult =  $PaymentGateway->checkPaymentResponse({
                        'Dispatcher'        => LoadPaymentDispatcher(),
                        'Shop'              => $Shop,
                        'CallbackParams'    => $CallbackParams
                    });
    };
    if (ExistsError()) {
        my $Error = GetError();
        $Error->vars->{'ShopAlias'} = $Shop->alias;
        LogError($Error);
        $hResult = {
            'ErrorCode'         => 'CreatePayment_Failed',
            'ErrorViewObject'   => $Shop
        };
    }

    if ($hResult->{'ErrorCode'}) {
        if ($Shop->isUnity()) {
            if (defined $hResult->{'Order'}) {
                $Servlet->vars('ViewObjectID', $hResult->{'Order'}->id());
                $Servlet->vars('ViewAction', 'ViewMultiCheckoutCustomerOrder');
            } else { # 'ViewMultiCheckoutCustomerOrder' action doesn't exist at class Shop
                $Servlet->redirect($hResult->{'WebUrlUnitySSL'});
            }
            return;
        } else {
            $Servlet->form->executeFormError({
                'Name'       => 'Payment',
                'Reason'     => $hResult->{'ErrorCode'},
                'ViewAction' => 'ViewPaymentPayboxResult',
                'ObjectID'   => $hResult->{'ErrorViewObject'}->id,
            });
        }
    }

    if (defined $hResult->{'Order'}) {
        my $Order = $hResult->{'Order'};
        $Servlet->vars('ViewObjectID', $Order->id());
        $Servlet->registerSession($Order->get('User'), 0);
        if ($Shop->isUnity()) {
            $Servlet->vars('ViewAction', 'ViewMultiCheckoutCustomerOrder');
        }
    } else {
        if ($Shop->isUnity()) { # 'ViewMultiCheckoutCustomerOrder' action doesn't exist at class Shop
            $Servlet->redirect($hResult->{'WebUrlUnitySSL'});
        }
    }

    return;
}

#==================================================================================================
# Handler triggered directly from the Paybox service
#==================================================================================================
sub CallbackPayment {
    my $self = shift;
    my ($Servlet) = @_;

    GetLog('Paybox')->debug('CallbackPayment');


    LogCommunication('Callback parameters', $Servlet->params, 'Paybox');
    $Servlet->params('ContentType', 'text/plain');

    my $Shop = $Servlet->object;
    my $CallbackParams = DE_EPAGES::Paybox::API::PaymentCallbackParams->new($Servlet->params);
    eval {
        my $GatewayConfigurator = LoadPaymentGatewayConfigurator( $CallbackParams->getPaymentMethodID() );
        my $PaymentGateway = LoadPaymentGateway($GatewayConfigurator);
        $PaymentGateway->processPaymentResponse({
            'Dispatcher'        => LoadPaymentDispatcher(),
            'Shop'              => $Shop,
            'CallbackParams'    => $CallbackParams
        });
        $Servlet->writeContentOutput('OK');
    };
    if (ExistsError()) {
        my $Error = GetError();
        $Error->vars->{'ShopAlias'} = $Shop->alias;
        LogError($Error);
        $Servlet->writeContentOutput('ERROR');
    }

    return;
}

1;
