#========================================================================================
# package      DE_EPAGES::Spreedly::UI::PaymentMethodSpreedlyAuthorize
# base         DE_EPAGES::Spreedly::UI::PaymentMethodSpreedly
# state        private
#----------------------------------------------------------------------------------------
# description  UI Controller for PaymentMethodSpreedlyAuthorize
#========================================================================================
package DE_EPAGES::Spreedly::UI::PaymentMethodSpreedlyAuthorize;
use base DE_EPAGES::Spreedly::UI::PaymentMethodSpreedly;

use DE_EPAGES::Core::API::PerlTools qw ( isValid );

use strict;

use constant PAYMENT_TYPE_AUTHORIZE => 'SpreedlyAuthorize';

#========================================================================================
# function     SaveSettings
# state        public
#----------------------------------------------------------------------------------------
# syntax       SaveSettings( $Servlet );
#----------------------------------------------------------------------------------------
# description  UI Controller to save settings on the MBO settings page.
#----------------------------------------------------------------------------------------
# input        $Servlet | Servlet | DE_EPAGES::Presentation::Servlet::BasePermission
#========================================================================================
sub SaveSettings {
    my $self = shift;
    my ($Servlet) = @_;

    my $Form = $Servlet->form();
    my $APILoginID = $Form->value('APILoginID');
    my $TransactionKey = $Form->value('TransactionKey');

    if (isValid($APILoginID) && isValid($TransactionKey)) {
        $self->_createGateway($APILoginID, $TransactionKey, $Servlet);
    }

    my $PaymentMethod = $Servlet->object();
    $Form->form($PaymentMethod, 'SpreedlyAuthorizeSettings');

    $self->SUPER::SaveSettings($Servlet);

}

#---------------------------------------------------------------------------
#  Private methods
#---------------------------------------------------------------------------
sub _createGateway {
    my $self = shift;
    my ($APILoginID, $TransactionKey, $Servlet) = @_;

    my $hAdditionalBodyParams = {
        'api_login_id' => $APILoginID,
        'transaction_key' => $TransactionKey,
    };

    my $PaymentMethodSpreedly = DE_EPAGES::Spreedly::UI::PaymentMethodSpreedly->new();
    $PaymentMethodSpreedly->SaveCredentials($Servlet, PAYMENT_TYPE_AUTHORIZE, $hAdditionalBodyParams);

    return;
}

1;
