#========================================================================================
# package      DE_EPAGES::Spreedly::UI::PaymentMethodSpreedlyPayULatam
# base         DE_EPAGES::Spreedly::UI::PaymentMethodSpreedly
# state        private
#----------------------------------------------------------------------------------------
# description  UI Controller for PaymentMethodSpreedlyPayULatam
#========================================================================================
package DE_EPAGES::Spreedly::UI::PaymentMethodSpreedlyPayULatam;
use base DE_EPAGES::Spreedly::UI::PaymentMethodSpreedly;

use DE_EPAGES::Core::API::PerlTools qw ( isValid );

use strict;

use constant PAYMENT_TYPE_PAYU_LATAM => 'SpreedlyPayULatam';

#========================================================================================
# function     SaveSettings
# state        public
#----------------------------------------------------------------------------------------
# syntax       SaveSettings( $Servlet );
#----------------------------------------------------------------------------------------
# description  UI Controller to save settings on the MBO settings page.
#----------------------------------------------------------------------------------------
# input        $Servlet | Servlet | DE_EPAGES::Presentation::Servlet::BasePermission
#========================================================================================
sub SaveSettings {
    my $self = shift;
    my ($Servlet) = @_;

    my $Form = $Servlet->form();
    my $ApiLogin = $Form->value('ApiLogin');
    my $ApiKey = $Form->value('ApiKey');
    my $MerchantID = $Form->value('MerchantID');
    my $AccountID =  $Form->value('AccountID');
    my $PaymentCountry = $Form->value('PaymentCountry');

    if (isValid($ApiLogin) && isValid($ApiKey) && isValid($MerchantID)
     && isValid($AccountID) && isValid($PaymentCountry)) {
        $self->_createGateway($ApiLogin,$ApiKey,$MerchantID,$AccountID,$PaymentCountry,$Servlet);
    }

    my $PaymentMethod = $Servlet->object();
    $Form->form($PaymentMethod, 'SpreedlyPayULatamSettings');

    $self->SUPER::SaveSettings($Servlet);

}

#---------------------------------------------------------------------------
#  Private methods
#---------------------------------------------------------------------------
sub _createGateway {
    my $self = shift;
    my ($ApiLogin, $ApiKey, $MerchantID, $AccountID, $PaymentCountry, $Servlet) = @_;

    my $hAdditionalBodyParams = {
        'api_login'       => $ApiLogin,
        'api_key'         => $ApiKey,
        'merchant_id'     => $MerchantID,
        'account_id'      => $AccountID,
        'payment_country' => $PaymentCountry,
    };

    my $PaymentMethodSpreedly = DE_EPAGES::Spreedly::UI::PaymentMethodSpreedly->new();
    $PaymentMethodSpreedly->SaveCredentials($Servlet, PAYMENT_TYPE_PAYU_LATAM, $hAdditionalBodyParams);

    return;
}

1;
