#========================================================================================
# package      DE_EPAGES::Spreedly::UI::PaymentMethodSpreedlyPayeezy
# base         DE_EPAGES::Spreedly::UI::PaymentMethodSpreedly
# state        private
#----------------------------------------------------------------------------------------
# description  UI Controller for PaymentMethodSpreedlyPayeezy
#========================================================================================
package DE_EPAGES::Spreedly::UI::PaymentMethodSpreedlyPayeezy;
use base DE_EPAGES::Spreedly::UI::PaymentMethodSpreedly;

use DE_EPAGES::Core::API::PerlTools qw ( isValid );

use strict;

use constant PAYMENT_TYPE_PAYEEZY => 'SpreedlyPayeezy';

#========================================================================================
# function     SaveSettings
# state        public
#----------------------------------------------------------------------------------------
# syntax       SaveSettings( $Servlet );
#----------------------------------------------------------------------------------------
# description  UI Controller to save settings on the MBO settings page.
#----------------------------------------------------------------------------------------
# input        $Servlet | Servlet | DE_EPAGES::Presentation::Servlet::BasePermission
#========================================================================================
sub SaveSettings {
    my $self = shift;
    my ($Servlet) = @_;

    my $Form = $Servlet->form();
    my $ApiKey = $Form->value('ApiKey');
    my $ApiSecret = $Form->value('ApiSecret');
    my $ApiToken = $Form->value('ApiToken');

    if (isValid($ApiKey) && isValid($ApiSecret) && isValid($ApiToken)) {
        $self->_createGateway($ApiKey, $ApiSecret ,$ApiToken, $Servlet);
    }

    my $PaymentMethod = $Servlet->object();
    $Form->form($PaymentMethod, 'SpreedlyPayeezySettings');

    $self->SUPER::SaveSettings($Servlet);

}

#---------------------------------------------------------------------------
#  Private methods
#---------------------------------------------------------------------------
sub _createGateway {
    my $self = shift;
    my ($ApiKey, $ApiSecret ,$ApiToken, $Servlet) = @_;

    my $hAdditionalBodyParams = {
        'api_key' => $ApiKey,
        'api_secret' => $ApiSecret,
        'api_token' => $ApiToken,
    };

    my $PaymentMethodSpreedly = DE_EPAGES::Spreedly::UI::PaymentMethodSpreedly->new();
    $PaymentMethodSpreedly->SaveCredentials($Servlet, PAYMENT_TYPE_PAYEEZY, $hAdditionalBodyParams);

    return;
}

1;
